function [X, D] = filter_initial_eigenpairs(X_0, D_0, thr)

%
% CALLING SEQUENCE:
% 
% [X, D] = filter_initial_eigenpairs(X_0, D_0, thr)
%
% SYNOPSIS:
%
%    this function selects an eigenpairs if the eigenvalue is within a
%    certain limit. The filtered set of eigenpairs are returned.
%    This function is not written inline, because there might be other
%    strategies to select an eigenpair.
%   
% INPUT:
%
%    X_0     initial set of eigenvectors in columns.
%    D_0     initial set of eigenvalues as a diagonal matrix.
%    thr     eigenpairs are rejected is abs(1/eigenvalue) < thr.
%
% OUTPUT:
%
%    X       filtered set of eigenvectors in columns.
%    D       filtered set of eigenvalues as a diagonal matrix.
%
% AUTHOR / BUG REPORT
%
%    saptarshi.das@univie.ac.at
%
% LAST MODIFICATION:
%
%    Dec. 27, 2010, first lines of codes   
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  SELECT EIGENPAIRS WITH THE THRESHOLD
%

D = diag(D_0);
idx = find((1 ./ abs(D)) > thr);
X = X_0(:, idx);
D = D(idx);
D = diag(D);
