function [V, D] = initial_eigenpairs_using_random_rows(A, B);

%
%  CALLING SEQUENCE:
%
%    [V, D] = initial_eigenpairs_using_random_rows(A, B)
%
%  SYNOPSIS:
%
%    This function computes initial eigenpairs (eigenvalues, and eigenvectors)
%    of an overdermined eigenvalue problem. A random set of rows are selected
%    from the rectangular matrices A, and B, so as to form a pair of square 
%    matrices. The generalized eigenvalue and eigenvector of the square
%    matrix pair is returned.
%
%  INPUT:
%
%    A             a over determined (rectangular) matrix. 
%    B             a over determined (rectangular) matrix. 
%
%  OUTPUT:
%
%    V              a matrix with the eigenvectors in its columns.
%    D              a diagonal matrix with estimated eigenvalues as entries.
%
%  LAST MODIFICATION:
%
%    Dec. 22, 2010, added a line in synopsis.
%
%  BUG REPORT:
%
%    saptarshi.das@univie.ac.at
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  GET DIMENSION OF THE MATRIX
%

[M, N] = size(A);
if ([M, N] ~= size(B)) 
  error('dim:missmatch', 'A and B should be of same size')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  INDEX OF RANDOM ROWS
%

idx   = randperm(M);
idx(N+1:M) = [];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  EIGENPARIS FOR SQUARE MATRIX PAIRS 
%

[V, D] = eig(A(idx, :), B(idx, :));
