
function [V, D] = initial_eigenpairs_using_square_form(A, B);

%
%  CALLING SEQUENCE:
%
%    [V, D] = initial_eigenpairs_using_square_form(A, B)
%
%  SYNOPSIS:
%
%    This function computes initial eigenpairs (eigenvalues, and eigenvectors)
%    of an overdermined eigenvalue problem. The eigenpairs are computed 
%    as the generalized eigenpairs of the square matrix pencil formed 
%    by (B'*A, B'*B). This method for a starting eigenpairs was suggested
%    in Boutry et al. 2005 (SIAM J. Matrix Anal. App., Vol. 27, No. 2).
%    
%  INPUT:
%
%    A             a over determined (rectangular) matrix. 
%    B             a over determined (rectangular) matrix. 
%
%  OUTPUT:
%
%    V              a matrix with the eigenvectors in its columns.
%    D              a diagonal matrix with estimated eigenvalues as entries.
%
%  LAST MODIFICATION:
%
%    Jan. 12, 2011, a line on sanity check.
%
%  BUG REPORT:
%
%    saptarshi.das@univie.ac.at
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  SANITY CHECK
%

if (size(A) ~= size(B)) 
  error('dim:missmatch', 'A and B should be of same size')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  RETURN EIGENPAIR OF THE SQUARE MATRIX PENCIL
%

[V, D] = eig(B'*A, B'*B);
