function [obj, grad] = overdet_obj(param, R_x, R_lambda_x, E_x, x_x)

%  SYNOPSIS:
%
%    A function that computes the objective function of the overdetermined
%    eigen value problem. The function return the value of the objective
%    function [more description will be added].
%
%  INPUT:
%
%  param   the parameter over which the objective function is required to
%          be optimized.
%
%  R_x            pre-compputed value of R*x.
%
%  R_lambda_x     pre-compputed value of R_lambda*x.
%
%  E_x            pre-computed value of E*x.
%
%  x_x            precomputed value of x'*x.
%
%  TODO       add R_com1, R_com2, give it a better name
%
%  OUTPUT:
%
%  obj     the value of the objective function.
%

%  BUG REPORT:
%
%  saptarshi.das@univie.ac.at
%

param  = [1; param];
obj = (param' * R_lambda_x' * R_lambda_x * param ...
      + param' * E_x' * E_x * param ...
      - (abs(param' * R_x' * R_lambda_x * param))^2 ...
           / (param' * R_x' * R_x * param) ...
       ) / (param' * x_x * param);

obj = real(obj);

grad = (2*R_lambda_x'*(R_lambda_x*param)) * (param' * R_x' * R_x * param) ...
    + (param' * R_lambda_x' * R_lambda_x * param) * 2*(R_x'*R_x * param) ...
    + (2*E_x'*E_x*param) * (param' * R_x' * R_x * param) ...
    + (param' * E_x' * E_x * param) * 2*(R_x'*R_x * param) ...
    - 2*(R_x'*R_lambda_x*param + R_lambda_x'*R_x*param) * ...
      (param'*R_lambda_x'*R_x*param) ; %+ param'*R_x'*R_lambda_x*param);

grad =  grad ...
      - obj * (param' * R_x' * R_x * param) * (2*x_x*param) ...
      - obj * (param' * x_x * param) * (2*R_x'*R_x*param);

grad = real(grad);
grad = grad / ((param' * x_x * param)*(param' * R_x' * R_x * param));

grad(1) = [];
grad = real(grad); 

%  CHANGE LOG:
%
%  * Dec. 17, 2010 -- coding begins. 
%
